@@ -1,8 +1,6 @@
-# pylint: skip-file
-# type: ignore
-
-import os
+# pylint: disable=invalid-name
 
+from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import (
     QDialog,
     QLabel,
@@ -14,18 +12,17 @@ from PyQt5.QtWidgets import (
     QMessageBox,
     QFileDialog,
 )
-from PyQt5.QtGui import QIcon
 
 import trnsysGUI.BlockItem as _bi
 
 
-class BlockDlg(QDialog):
+class BlockDlg(QDialog):  # pylint: disable=too-many-instance-attributes
     def __init__(self, block: _bi.BlockItem, parent=None):
-        super(BlockDlg, self).__init__(parent)
+        super().__init__(parent)
         nameLabel = QLabel("Name:")
         self.logger = parent.logger
         self.block = block
-        self.le = QLineEdit(self.block.label.toPlainText())
+        self.lineEdit = QLineEdit(self.block.label.toPlainText())
         self.setWindowIcon(QIcon(block.pixmap()))
         self.loadButton = QPushButton("Load")
         self.okButton = QPushButton("OK")
@@ -55,7 +52,7 @@ class BlockDlg(QDialog):
         buttonLayout.addWidget(self.cancelButton)
         layout = QGridLayout()
         layout.addWidget(nameLabel, 0, 0)
-        layout.addWidget(self.le, 0, 1)
+        layout.addWidget(self.lineEdit, 0, 1)
         layout.addLayout(flipLayout, 1, 0, 2, 0)
         layout.addLayout(buttonLayout, 2, 0, 2, 0)
         self.setLayout(layout)
@@ -74,42 +71,35 @@ class BlockDlg(QDialog):
 
     def acceptedEdit(self):
         self.logger.debug("Changing displayName")
-        newName = self.le.text()
+        newName = self.lineEdit.text()
         if newName.lower() == str(self.block.displayName).lower():
             self.close()
-        elif newName != "" and not self.nameExists(newName):
-            self.block.setName(newName)
-            # self.block.label.setPlainText(newName)
-            # self.block.displayName = newName
-            self.close()
         elif newName == "":
             msgb = QMessageBox()
             msgb.setText("Please Enter a name!")
             msgb.exec()
-        elif self.nameExists(newName):
+        elif self.parent().nameExists(newName) or self.parent().nameExistsInDdckFolder(newName):
             msgb = QMessageBox()
             msgb.setText("Name already exist!")
             msgb.exec()
+        else:
+            self.block.setDisplayName(newName)
+            self.close()
 
     def setNewFlipStateH(self, state):
         self.block.updateFlipStateH(state)
+        self.block.updateSidesFlippedH()
 
     def setNewFlipStateV(self, state):
         self.block.updateFlipStateV(state)
+        self.block.updateSidesFlippedV()
 
     def cancel(self):
         self.close()
 
-    def nameExists(self, n):
-        for t in self.parent().trnsysObj:
-            if str(t.displayName).lower() == n.lower():
-                return True
-        return False
-
     # unused
     def loadFile(self):
         self.logger.debug("Opening diagram")
-        # self.centralWidget.delBlocks()
         fileName = QFileDialog.getOpenFileName(self, "Open diagram", filter="*.ddck")[0]
         if fileName != "":
             if len(self.block.propertyFile) < 2:
@@ -119,8 +109,7 @@ class BlockDlg(QDialog):
                 self.block.propertyFile.append(fileName)
         else:
             self.logger.debug("No filename chosen")
-        pass
 
     def disableLoad(self):
-        if self.block.name == "TeePiece" or self.block.name == "WTap_main":
+        if self.block.name in ("TeePiece", "WTap_main"):
             self.loadButton.setDisabled(True)
