@@ -2,13 +2,13 @@
 # type: ignore
 
 import json
-import math as _math
 import os
 import pathlib as _pl
 import pkgutil as _pu
 import shutil
 import typing as _tp
 
+import math as _math
 from PyQt5 import QtGui
 from PyQt5.QtCore import QSize, Qt, QLineF, QFileInfo, QDir, QPointF, QEvent
 from PyQt5.QtGui import QColor, QPainter
@@ -35,13 +35,14 @@ from PyQt5.QtWidgets import (
 import pytrnsys.trnsys_util.deckUtils as _du
 import pytrnsys.utils.result as _res
 import trnsysGUI as _tgui
+import trnsysGUI.connection.names as _cnames
 import trnsysGUI.diagram.Encoder as _enc
 import trnsysGUI.errors as _errs
 import trnsysGUI.hydraulicLoops.edit as _hledit
 import trnsysGUI.hydraulicLoops.migration as _hlmig
 import trnsysGUI.hydraulicLoops.model as _hlm
 import trnsysGUI.images as _img
-import trnsysGUI.massFlowSolver as _mfs
+import trnsysGUI.internalPiping as _ip
 import trnsysGUI.placeholders as _ph
 from trnsysGUI.BlockDlg import BlockDlg
 from trnsysGUI.BlockItem import BlockItem
@@ -50,8 +51,8 @@ from trnsysGUI.FileOrderingDialog import FileOrderingDialog
 from trnsysGUI.GenericPortPairDlg import GenericPortPairDlg
 from trnsysGUI.Graphicaltem import GraphicalItem
 from trnsysGUI.LibraryModel import LibraryModel
-from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel
-from trnsysGUI.MyQTreeView import MyQTreeView
+from trnsysGUI.MyQFileSystemModel import MyQFileSystemModel  # type: ignore[attr-defined]
+from trnsysGUI.MyQTreeView import MyQTreeView  # type: ignore[attr-defined]
 from trnsysGUI.PortItemBase import PortItemBase
 from trnsysGUI.PumpDlg import PumpDlg
 from trnsysGUI.TVentil import TVentil
@@ -59,6 +60,7 @@ from trnsysGUI.TVentilDlg import TVentilDlg
 from trnsysGUI.connection.connectionBase import ConnectionBase
 from trnsysGUI.connection.createDoublePipeConnectionCommand import CreateDoublePipeConnectionCommand
 from trnsysGUI.connection.createSinglePipeConnectionCommand import CreateSinglePipeConnectionCommand
+from trnsysGUI.connection.doublePipeConnection import DoublePipeConnection
 from trnsysGUI.connection.singlePipeConnection import SinglePipeConnection
 from trnsysGUI.diagram.Decoder import Decoder
 from trnsysGUI.diagram.scene import Scene
@@ -281,7 +283,7 @@ class Editor(QWidget):
         self.connectionList = []
         self.trnsysObj = []
         self.graphicalObj = []
-        self.fluids = _hlm.Fluids([])
+        self.fluids = _hlm.Fluids.createDefault()
         self.hydraulicLoops = _hlm.HydraulicLoops([])
 
         self.copyGroupList = QGraphicsItemGroup()
@@ -512,20 +514,51 @@ class Editor(QWidget):
                     fullExportText += line
             header.close()
         elif exportTo == "ddck":
-            fullExportText += "*************************************\n"
-            fullExportText += "** BEGIN hydraulic.ddck\n"
-            fullExportText += "*************************************\n\n"
-            fullExportText += "*************************************\n"
-            fullExportText += "** Outputs to energy balance in kWh\n"
-            fullExportText += (
-                "** Following this naming standard : qSysIn_name, qSysOut_name, elSysIn_name, elSysOut_name\n"
-            )
-            fullExportText += "*************************************\n"
-            fullExportText += "EQUATIONS 1\n"
-            fullExportText += "qSysOut_PipeLoss = PipeLossTot\n"
+            SinglePipeTotals = _cnames.EnergyBalanceTotals.SinglePipe
+            DoublePipeTotals = _cnames.EnergyBalanceTotals.DoublePipe
+
+            singlePipesWithTrnsysUnits = [
+                o for o in self.trnsysObj if isinstance(o, SinglePipeConnection) and o.shallCreateTrnsysUnit
+            ]
+            singlePipeEnergyBalanceEquations = ""
+            if singlePipesWithTrnsysUnits:
+                singlePipeEnergyBalanceEquations = f"""\
+EQUATIONS 2
+*** single pipes
+qSysOut_PipeLoss = {SinglePipeTotals.DISSIPATED}
+qSysOut_{SinglePipeTotals.PIPE_INTERNAL_CHANGE} = {SinglePipeTotals.PIPE_INTERNAL_CHANGE}
+
+"""
+            doublePipes = [o for o in self.trnsysObj if isinstance(o, DoublePipeConnection)]
+            doublePipesEnergyBalanceEquations = ""
+            if doublePipes:
+                doublePipesEnergyBalanceEquations = f"""\
+EQUATIONS 3
+*** double pipes
+qSysOut_{DoublePipeTotals.DISSIPATION_TO_FAR_FIELD} = {DoublePipeTotals.DISSIPATION_TO_FAR_FIELD}
+qSysOut_{DoublePipeTotals.PIPE_INTERNAL_CHANGE} = {DoublePipeTotals.PIPE_INTERNAL_CHANGE}
+qSysOut_{DoublePipeTotals.SOIL_INTERNAL_CHANGE} = {DoublePipeTotals.SOIL_INTERNAL_CHANGE}
+"""
+            energyBalanceEquations = f"""\
+*************************************
+** BEGIN hydraulic.ddck
+*************************************
+
+*************************************
+** Outputs to energy balance in kWh
+
+** Following this naming standard : qSysIn_name, qSysOut_name, elSysIn_name, elSysOut_name
+
+*************************************
+{singlePipeEnergyBalanceEquations}
+{doublePipesEnergyBalanceEquations}
+
+"""
+
+            fullExportText += energyBalanceEquations
 
         simulationUnit = 450
-        simulationType = 935
+        simulationType = 9351
         descConnLength = 15
 
         exporter = self._createExporter()
@@ -549,7 +582,8 @@ class Editor(QWidget):
         fullExportText += exporter.exportFluids() + "\n"
         fullExportText += exporter.exportHydraulicLoops() + "\n"
         fullExportText += exporter.exportPipeAndTeeTypesForTemp(simulationUnit + 1)  # DC-ERROR
-        fullExportText += exporter.exportPrintPipeLosses()
+        fullExportText += exporter.exportSinglePipeEnergyBalanceVariables()
+        fullExportText += exporter.exportDoublePipeEnergyBalanceVariables()
 
         fullExportText += exporter.exportMassFlowPrinter(self.printerUnitnr, 15)
         fullExportText += exporter.exportTempPrinter(self.printerUnitnr + 1, 15)
@@ -598,13 +632,13 @@ class Editor(QWidget):
         )
         return exporter
 
-    def _getMassFlowContributors(self) -> _tp.Sequence[_mfs.MassFlowNetworkContributorMixin]:
-        massFlowContributors = [o for o in self.trnsysObj if isinstance(o, _mfs.MassFlowNetworkContributorMixin)]
+    def _getMassFlowContributors(self) -> _tp.Sequence[_ip.HasInternalPiping]:
+        massFlowContributors = [o for o in self.trnsysObj if isinstance(o, _ip.HasInternalPiping)]
         return massFlowContributors
 
     def _isHydraulicConnected(self) -> bool:
         for obj in self.trnsysObj:
-            if not isinstance(obj, _mfs.MassFlowNetworkContributorMixin):
+            if not isinstance(obj, _ip.HasInternalPiping):
                 continue
 
             internalPiping = obj.getInternalPiping()
@@ -688,7 +722,7 @@ class Editor(QWidget):
         return hydCtrlPath
 
     def sortTrnsysObj(self):
-        res = self.trnsysObj.sort(key=self.sortId)
+        self.trnsysObj.sort(key=self.sortId)
         for s in self.trnsysObj:
             self.logger.debug("s has tr id " + str(s.trnsysId) + " has dname " + s.displayName)
 
@@ -718,11 +752,16 @@ class Editor(QWidget):
         """
         self.hydraulicLoops.clear()
 
-        while len(self.trnsysObj) > 0:
-            self.logger.info("In deleting...")
-            self.trnsysObj[0].deleteBlock()
+        while self.trnsysObj:
+            trnsysObject = self.trnsysObj[0]
+            if isinstance(trnsysObject, BlockItem):
+                trnsysObject.deleteBlock()
+            elif isinstance(trnsysObject, ConnectionBase):
+                trnsysObject.deleteConn()
+            else:
+                raise AssertionError(f"Don't know how to delete {trnsysObject}.")
 
-        while len(self.graphicalObj) > 0:
+        while self.graphicalObj:
             self.graphicalObj[0].deleteBlock()
 
     # Encoding / decoding
@@ -812,13 +851,14 @@ class Editor(QWidget):
         for t in self.trnsysObj:
             t.assignIDsToUninitializedValuesAfterJsonFormatMigration(self.idGen)
 
-            self.logger.debug("Tr obj is" + str(t) + " " + str(t.trnsysId))
             if hasattr(t, "isTempering"):
                 self.logger.debug("tv has " + str(t.isTempering))
 
         self._decodeHydraulicLoops(blocklist)
 
-    def _decodeHydraulicLoops(self, blocklist):
+        self._setHydraulicLoopsOnStorageTanks()
+
+    def _decodeHydraulicLoops(self, blocklist) -> None:
         singlePipeConnections = [c for c in self.connectionList if isinstance(c, SinglePipeConnection)]
         if "hydraulicLoops" not in blocklist:
             hydraulicLoops = _hlmig.createLoops(singlePipeConnections, self.fluids.WATER)
@@ -830,6 +870,15 @@ class Editor(QWidget):
 
         self.hydraulicLoops = hydraulicLoops
 
+    def _setHydraulicLoopsOnStorageTanks(self) -> None:
+        for trnsysObject in self.trnsysObj:
+            if not isinstance(trnsysObject, StorageTank):
+                continue
+
+            storageTank = trnsysObject
+
+            storageTank.setHydraulicLoops(self.hydraulicLoops)
+
     def exportSvg(self):
         """
         For exporting a svg file (text is still too large)
@@ -850,7 +899,7 @@ class Editor(QWidget):
         self.diagramScene.render(painter)
         painter.end()
 
-    def exportDdckPlaceHolderValuesJsonFile(self) -> _res.Result[None]:
+    def exportDdckPlaceHolderValuesJsonFile(self, shallShowMessageOnSuccess: bool = True) -> _res.Result[None]:
         if not self._isHydraulicConnected():
             return _res.Error(f"You need to connect all port items before you can export the hydraulics.")
 
@@ -880,19 +929,20 @@ class Editor(QWidget):
         if _res.isError(result):
             return _res.error(result)
 
-        msgb = QMessageBox()
-        msgb.setWindowTitle("Saved successfully")
-        msgb.setText(f"Saved place holder values JSON file at {jsonFilePath}.")
-        msgb.setStandardButtons(QMessageBox.Ok)
-        msgb.setDefaultButton(QMessageBox.Ok)
-        msgb.exec()
+        if shallShowMessageOnSuccess:
+            msgb = QMessageBox()
+            msgb.setWindowTitle("Saved successfully")
+            msgb.setText(f"Saved place holder values JSON file at {jsonFilePath}.")
+            msgb.setStandardButtons(QMessageBox.Ok)
+            msgb.setDefaultButton(QMessageBox.Ok)
+            msgb.exec()
 
         return None
 
     def encodeDdckPlaceHolderValuesToJson(self, filePath: _pl.Path) -> _res.Result[None]:
         ddckDirNames = self._getDdckDirNames()
 
-        result = _ph.getPlaceholderValues(ddckDirNames, self.trnsysObj)
+        result = _ph.getPlaceholderValues(ddckDirNames, self.trnsysObj, self.hydraulicLoops)
         if _res.isError(result):
             return _res.error(result)
 
@@ -1064,9 +1114,6 @@ class Editor(QWidget):
         painter.drawEllipse(20, 20, 20, 20)
         painter.end()
 
-    def setTrnsysIdBack(self):
-        self.idGen.trnsysID = max(t.trnsysId for t in self.trnsysObj)
-
     def findStorageCorrespPorts1(self, portList):
         """
         This function gets the ports on the other side of pipes connected to a port of the StorageTank. Unused
@@ -1097,7 +1144,7 @@ class Editor(QWidget):
                     else:
                         self.logger.debug("Port is not fromPort nor toPort")
 
-        # [print(p.parent.displayName) for p in res]
+        # [print(p.parent.newDisplayName) for p in res]
         return res
 
     def printPDF(self):
